diff --git a/README.md b/README.md
index 683c190..e615f09 100644
--- a/README.md
+++ b/README.md
@@ -155,7 +155,7 @@ You can also access the database cli shell as:
sudo -i # switch to the root user.
systemctl stop nexus # make sure nexus is not running while you use the database.
su -s /bin/bash nexus # switch to the nexus user.
-nexus_home=/opt/nexus/nexus-3.93.1-04 # make sure you have the correct version here.
+nexus_home=/opt/nexus/nexus-3.95.3-02 # make sure you have the correct version here.
nexus_data="$(realpath $nexus_home/../sonatype-work/nexus3)"
install -d $nexus_data/../tmp
rm -f $nexus_data/../tmp/h2-*.jar
diff --git a/Vagrantfile b/Vagrantfile
index f523ff2..fe8edc8 100644
--- a/Vagrantfile
+++ b/Vagrantfile
@@ -7,7 +7,7 @@ nexus_ip = '192.168.56.3'
Vagrant.configure(2) do |config|
config.vm.provider :libvirt do |lv, config|
- lv.memory = 2048
+ lv.memory = 2*1024
lv.cpus = 4
lv.cpu_mode = 'host-passthrough'
lv.keymap = 'pt'
@@ -19,7 +19,7 @@ Vagrant.configure(2) do |config|
config.vm.hostname = nexus_domain
config.vm.network 'private_network', ip: nexus_ip
config.vm.provider :libvirt do |lv, config|
- lv.memory = 3*1024
+ lv.memory = 6*1024
lv.machine_virtual_size = 32 # [GiB]
config.vm.synced_folder '.', '/vagrant', type: 'nfs', nfs_version: '4.2', nfs_udp: false
end
diff --git a/provision/provision-nexus/Makefile b/provision/provision-nexus/Makefile
index 2e6f05e..96aa2b9 100644
--- a/provision/provision-nexus/Makefile
+++ b/provision/provision-nexus/Makefile
@@ -17,7 +17,7 @@ binaries: binaries-download
binaries-download:
mkdir -p binaries
- wget -qO- https://download.sonatype.com/nexus/3/nexus-3.93.1-04-unix.tar.gz \
+ wget -qO- https://download.sonatype.com/nexus/3/nexus-3.95.3-02-unix.tar.gz \
| tar xzf - --strip-components 1 -C binaries
clean:
diff --git a/provision/provision-nexus/pom.xml b/provision/provision-nexus/pom.xml
index 480421c..229d901 100644
--- a/provision/provision-nexus/pom.xml
+++ b/provision/provision-nexus/pom.xml
@@ -8,7 +8,7 @@
1.0-SNAPSHOT
- 3.93.1-04
+ 3.95.3-02
diff --git a/provision/provision-nexus.sh b/provision/provision-nexus.sh
index c546377..0dbedfb 100644
--- a/provision/provision-nexus.sh
+++ b/provision/provision-nexus.sh
@@ -35,12 +35,12 @@ pushd /opt/nexus
# see https://help.sonatype.com/en/download-archives---repository-manager-3.html
# see https://help.sonatype.com/en/release-notes.html
# see https://help.sonatype.com/en/sonatype-nexus-repository.html
-nexus_version=3.93.1-04
+nexus_version=3.95.3-02
nexus_home=/opt/nexus/nexus-$nexus_version
nexus_tarball=nexus-$nexus_version-linux-x86_64.tar.gz
nexus_download_url=https://download.sonatype.com/nexus/3/$nexus_tarball
wget -q $nexus_download_url
-tar xf $nexus_tarball # NB this creates the $nexus_home (e.g. nexus-3.93.1-04) and sonatype-work directories.
+tar xf $nexus_tarball # NB this creates the $nexus_home (e.g. nexus-3.95.3-02) and sonatype-work directories.
rm $nexus_tarball
sed -i -E 's,#!.+,#!/usr/bin/bash,g' "$nexus_home/bin/nexus"
install -d -o nexus -g nexus -m 700 .java # java preferences are saved here (the default java.util.prefs.userRoot preference).